@@ -1,5 +1,5 @@
 /**
- * SPDX-FileCopyrightText: 2021 Bart De Vries <bart@mogwai.be>
+ * SPDX-FileCopyrightText: 2021-2022 Bart De Vries <bart@mogwai.be>
  *
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
@@ -91,6 +91,11 @@ Q_SIGNALS:
     void bulkReadStatusActionFinished();
     void bulkNewStatusActionFinished();
 
+    // this will relay the AudioManager::playbackRateChanged signal; this is
+    // required to avoid a dependency loop on startup
+    // TODO: find less hackish solution
+    void playbackRateChanged();
+
 private:
     DataManager();
     void loadFeed(const QString &feedurl) const;
